Index: Source/core/rendering/RenderBlockFlow.h |
diff --git a/Source/core/rendering/RenderBlockFlow.h b/Source/core/rendering/RenderBlockFlow.h |
index efb717e4eb8557ccaa97191122df8b487f3e2324..3e4cb22150e4c5bcdda5660932ae3c63f8ec7d51 100644 |
--- a/Source/core/rendering/RenderBlockFlow.h |
+++ b/Source/core/rendering/RenderBlockFlow.h |
@@ -441,7 +441,10 @@ private: |
LayoutUnit applyAfterBreak(RenderBox* child, LayoutUnit logicalOffset, MarginInfo&); // If the child has an after break, then return a new offset that shifts to the top of the next page/column. |
LayoutUnit adjustBlockChildForPagination(LayoutUnit logicalTopAfterClear, LayoutUnit estimateWithoutPagination, RenderBox* child, bool atBeforeSideOfBlock); |
- void adjustLinePositionForPagination(RootInlineBox*, LayoutUnit& deltaOffset, RenderFlowThread*); // Computes a deltaOffset value that put a line at the top of the next page if it doesn't fit on the current page. |
+ // Computes a deltaOffset value that put a line at the top of the next page if it doesn't fit on the current page. |
+ void adjustLinePositionForPagination(RootInlineBox*, LayoutUnit& deltaOffset, RenderFlowThread*); |
+ // If the child is unsplittable and can't fit on the current page, return the top of the next page/column. |
+ LayoutUnit adjustForUnsplittableChild(RenderBox*, LayoutUnit logicalOffset, bool includeMargins = false); |
rune
2014/09/25 11:13:22
Adjust what? I know you didn't invent this method
mstensho (USE GERRIT)
2014/09/26 11:09:01
adjustPositionForUnsplittableChild()?
adjustUnspli
|
// Used to store state between styleWillChange and styleDidChange |
static bool s_canPropagateFloatIntoSibling; |